@@ -7,6 +7,7 @@
 #define __SOUNDLIB_H
 
 #include <linux/sound.h>
+#include <unistd.h>
 
 /*
  *  version.h
@@ -14,7 +15,7 @@
 
 #define SOUNDLIB_VERSION_MAJOR		0
 #define SOUNDLIB_VERSION_MINOR		0
-#define SOUNDLIB_VERSION_SUBMINOR	4
+#define SOUNDLIB_VERSION_SUBMINOR	5
 #define SOUNDLIB_VERSION		( ( LIBULTRA_VERSION_MAJOR << 16 ) | ( LIBULTRA_VERSION_MINOR << 8 ) | LIB_ULTRA_VERSION_SUBMINOR )
 
 /*
@@ -46,12 +47,15 @@ extern "C" {
 #endif
 
 int snd_cards( void );
+unsigned int snd_cards_mask( void );
  
 int snd_ctl_open( void **handle, int card );
 int snd_ctl_close( void *handle );
 int snd_ctl_file_descriptor( void *handle );
 int snd_ctl_hw_info( void *handle, struct snd_ctl_hw_info *info );
 int snd_ctl_pcm_info( void *handle, int dev, snd_pcm_info_t *info );
+int snd_ctl_pcm_playback_info( void *handle, int dev, snd_pcm_playback_info_t *info );
+int snd_ctl_pcm_record_info( void *handle, int dev, snd_pcm_record_info_t *info );
 int snd_ctl_mixer_info( void *handle, int dev, snd_mixer_info_t *info );
 
 #ifdef __cplusplus
